@@ -1,15 +1,24 @@
 ## ----include=FALSE-------------------------------------------------------
 library(knitr)
 opts_chunk$set(
-concordance=TRUE,
-results="tex")
+concordance = TRUE,
+results = "tex")
 options(results = 'tex') # for pqR
 
-## ----prep, echo=FALSE---------------------------------------------------------------------------------------
+## ----prep, echo=FALSE, results='hide'-----------------------------------------------------------------------
 library(knitr)
 options(width=110, digits=2)
 opts_chunk$set(comment = "", warning = FALSE, message = TRUE, echo = TRUE, size="footnotesize")
 # read_chunk("some/script/I/want/to/load.R")
+tmp <- tempdir()
+suppressPackageStartupMessages(library(vegdata))
+options(tv_home = tmp)
+dir.create(file.path(tmp, 'Species'))
+dir.create(file.path(tmp, 'Popup'))
+dir.create(file.path(tmp, 'Data'))
+file.copy(from = file.path(path.package("vegdata"), 'tvdata', 'Popup'), to = tmp, recursive = TRUE)
+file.copy(from = file.path(path.package("vegdata"), 'tvdata', 'Species'), to = tmp, recursive = TRUE)
+file.copy(from = file.path(path.package("vegdata"), 'tvdata', 'Data'), to = tmp, recursive = TRUE)
 
 ## ----load, results='hide'-----------------------------------------------------------------------------------
 library(vegdata)
@@ -69,19 +78,19 @@ tmp$newTaxon <- tax(tmp$TaxonUsageID, refl='GermanSL 1.3')$TaxonName
 ## ----print.coarsen------------------------------------------------------------------------------------------
 head(tmp[,c('OriginalName','newTaxon')], 10)
 
-## ----coverperc, echo=2:4------------------------------------------------------------------------------------
+## ----coverperc, echo=2:4, eval=TRUE-------------------------------------------------------------------------
 options(width=120)
 obs <- tv.obs(db)
-obs <- tv.coverperc(db, obs)
+# obs <- tv.coverperc(db, obs)
 tail(obs)
 options(width=110)
 
 ## ----pseudo1, eval=FALSE------------------------------------------------------------------------------------
 #  data(lc.0)
+#  obs <- tv.obs(db)
 #  tv.veg(db, pseudo = list(lc.0, c("LAYER")), lc = "layer")
 
-## ----lc0, echo=FALSE, warning=FALSE-------------------------------------------------------------------------
-data(lc.0)
+## ----lc0, warning=FALSE-------------------------------------------------------------------------------------
 tmp <- tv.veg(db, tax=FALSE, pseudo = list(lc.0, "LAYER"), lc = "layer", quiet=TRUE)
 names(tmp)
 
@@ -93,7 +102,6 @@ names(tv.veg(db, tax=FALSE, pseudo=comb, quiet=TRUE))
 data(lc.1)
 veg <- tv.veg(db, lc = "sum", pseudo = list(lc.1, 'LAYER'), dec = 1, check.critical = FALSE)
 
-
 ## ----layerdiff----------------------------------------------------------------------------------------------
 veg[,1:10]
 
